import styles from "../../styles";
import {
  Button,
  FormControl,
  InputLabel,
  MenuItem,
  Select,
  SelectChangeEvent,
} from "@mui/material";
import HourglassBottomIcon from "@mui/icons-material/HourglassBottom";
import CheckCircleIcon from "@mui/icons-material/CheckCircle";
import FlashOffIcon from "@mui/icons-material/FlashOff";
import CheckCircleOutlineIcon from "@mui/icons-material/CheckCircleOutline";
import ShoppingCartCheckoutIcon from "@mui/icons-material/ShoppingCartCheckout";
import AssignmentReturnedIcon from "@mui/icons-material/AssignmentReturned";
import CancelOutlinedIcon from "@mui/icons-material/CancelOutlined";
import CancelIcon from "@mui/icons-material/Cancel";
import ClearAllIcon from "@mui/icons-material/ClearAll";

type props = {
  filter: string;
  setFilter: React.Dispatch<React.SetStateAction<string>>;
};

export default function TransactionFilterMenu(props: props) {
  return (
    <>
      <p
        style={{
          ...styles.text_dark,
          ...styles.text_L,
        }}
      >
        Transactions
      </p>

      <div
        style={{
          ...styles.flex_row,
          ...{
            alignSelf: "center",
            justifyContent: "center",
            flexWrap: "wrap",
          },
        }}
      >
        <FormControl sx={{ width: "384px" }}>
          <InputLabel style={{ backgroundColor: "white", padding: 0 }}>
            Filter Transactions
          </InputLabel>
          <Select
            value={props.filter}
            onChange={(e: SelectChangeEvent<string>) =>
              props.setFilter(e.target.value)
            }
          >
            <MenuItem value={""}>
              <Button
                style={{
                  ...styles.row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <ClearAllIcon style={styles.student_filter_item} />
                <p
                  style={{
                    ...styles.text_dark,
                    ...styles.text_M,
                  }}
                >
                  All
                </p>
              </Button>
            </MenuItem>
            <MenuItem value={"Pending Approval"}>
              <Button
                style={{
                  ...styles.row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <HourglassBottomIcon style={styles.student_filter_item} />
                <div
                  style={{
                    ...styles.flex_column,
                  }}
                >
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_M,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Pending
                  </p>
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_XS,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Awaiting teacher approval
                  </p>
                </div>
              </Button>
            </MenuItem>
            <MenuItem value={"Approved"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <CheckCircleOutlineIcon style={styles.student_filter_item} />
                <div
                  style={{
                    ...styles.flex_column,
                  }}
                >
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_M,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Approved
                  </p>
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_XS,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    To be delivered by technician
                  </p>
                </div>
              </Button>
            </MenuItem>
            <MenuItem value={"Rejected"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <CancelOutlinedIcon style={styles.student_filter_item} />
                <div
                  style={{
                    ...styles.flex_column,
                  }}
                >
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_M,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Rejected
                  </p>
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_XS,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Denied by teacher
                  </p>
                </div>
              </Button>
            </MenuItem>
            <MenuItem value={"Borrowed"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <ShoppingCartCheckoutIcon style={styles.student_filter_item} />
                <div
                  style={{
                    ...styles.flex_column,
                  }}
                >
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_M,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    On-Borrow
                  </p>
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_XS,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Items currently with student
                  </p>
                </div>
              </Button>
            </MenuItem>
            <MenuItem value={"Cancelled"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <CancelIcon style={styles.student_filter_item} />
                <div
                  style={{
                    ...styles.flex_column,
                  }}
                >
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_M,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Cancelled
                  </p>
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_XS,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Approved but was not delivered to student
                  </p>
                </div>
              </Button>
            </MenuItem>
            <MenuItem value={"Returned: Pending Checking"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <AssignmentReturnedIcon style={styles.student_filter_item} />
                <div
                  style={{
                    ...styles.flex_column,
                  }}
                >
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_M,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Returned: Pending
                  </p>
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_XS,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Being checked for any breakages
                  </p>
                </div>
              </Button>
            </MenuItem>
            <MenuItem value={"Finalized"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <CheckCircleIcon style={styles.student_filter_item} />
                <div
                  style={{
                    ...styles.flex_column,
                  }}
                >
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_M,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Finalized
                  </p>
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_XS,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    Completed transaction without breakages
                  </p>
                </div>
              </Button>
            </MenuItem>
            <MenuItem value={"With Breakages: Pending Resolution"}>
              <Button
                style={{
                  ...styles.flex_row,
                  ...{
                    alignSelf: "center",
                    justifyContent: "center",
                    flexWrap: "wrap",
                  },
                }}
              >
                <FlashOffIcon style={styles.student_filter_item} />
                <div
                  style={{
                    ...styles.flex_column,
                  }}
                >
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_M,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    With Breakages
                  </p>
                  <p
                    style={{
                      ...styles.text_dark,
                      ...styles.text_XS,
                      ...{ margin: 0, textAlign: "left" },
                    }}
                  >
                    With broken items awaiting reimbursement
                  </p>
                </div>
              </Button>
            </MenuItem>
          </Select>
        </FormControl>
      </div>
    </>
  );
}
