import { Document, Page, Text, View } from "@react-pdf/renderer";
import { TransactionListType } from "../Types/Types";
import { colors } from "../../styles";
import count_transaction_equipments from "../../CountTransactionEquipments/CountTransactionEquipments";
import {
  filter_today,
  filter_thismonth,
} from "../FilterTransaction/FilterTransaction";

type props = {
  transactions: TransactionListType | [];
  filter: "Day" | "Month";
};

export default function TransactionReportPDF(props: props) {
  const transactions_today = filter_today(props.transactions);
  const transactions_thismonth = filter_thismonth(props.transactions);
  return (
    <Document>
      <Page size={"A4"}>
        <Text
          style={{
            color: colors.font_dark,
            fontSize: 16,
            alignSelf: "center",
            justifyContent: "center",
          }}
        >
          Daily Transaction Report
        </Text>
        <View
          style={{
            alignSelf: "center",
            justifyContent: "center",
            width: "512px",
            backgroundColor: colors.header_color,
            borderRadius: 16,
            margin: "8px",
            padding: "8px",
          }}
        >
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Total Equipments Processed:{" "}
            {count_transaction_equipments(transactions_today)}
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Total Transactions: {transactions_today.length}
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Rejected Transactions:{" "}
            {
              transactions_today.filter(
                (transaction) => transaction.transaction_status == "Rejected"
              ).length
            }
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Rejected Transactions:{" "}
            {
              transactions_today.filter(
                (transaction) => transaction.transaction_status == "Rejected"
              ).length
            }
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Finalized Transactions:{" "}
            {
              transactions_today.filter(
                (transaction) => transaction.transaction_status == "Finalized"
              ).length
            }
          </Text>
        </View>
        <Text
          style={{
            color: colors.font_dark,
            fontSize: 16,
            alignSelf: "center",
            justifyContent: "center",
          }}
        >
          Monthly Transaction Report
        </Text>
        <View
          style={{
            alignSelf: "center",
            justifyContent: "center",
            width: "512px",
            backgroundColor: colors.header_color,
            borderRadius: 16,
            margin: "8px",
            padding: "8px",
          }}
        >
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Total Equipments Processed:{" "}
            {count_transaction_equipments(transactions_thismonth)}
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Total Transactions: {transactions_thismonth.length}
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Rejected Transactions:{" "}
            {
              transactions_thismonth.filter(
                (transaction) => transaction.transaction_status == "Rejected"
              ).length
            }
          </Text>
          <Text
            style={{
              color: colors.font_dark,
              fontSize: 16,
              textAlign: "center",
            }}
          >
            Finalized Transactions:{" "}
            {
              transactions_thismonth.filter(
                (transaction) => transaction.transaction_status == "Finalized"
              ).length
            }
          </Text>
        </View>
      </Page>
    </Document>
  );
}
