import { useQuery } from "@tanstack/react-query";
import Header from "../../Components/Header/Header";
import styles from "../../styles";
import { TransactionsAPI } from "../../Components/API/API";
import { CircularProgress } from "@mui/material";
import { PDFDownloadLink, PDFViewer } from "@react-pdf/renderer";
import TransactionReportPDF from "../../Components/TransactionReportPDF/TransactionReportPDF";

export default function TransactionReportPage() {
  const transactions = useQuery({
    queryKey: ["transactions"],
    queryFn: TransactionsAPI,
  });
  if (transactions.isLoading) {
    return (
      <div style={styles.background}>
        <Header label={"Transactions"} />
        <div
          style={{
            ...styles.flex_column,
            ...{
              alignItems: "center",
              justifyContent: "center",
              paddingTop: "64px",
            },
          }}
        >
          <CircularProgress style={{ height: "128px", width: "128px" }} />
          <p
            style={{
              ...styles.text_dark,
              ...styles.text_L,
            }}
          >
            Loading
          </p>
        </div>
      </div>
    );
  }
  return (
    <div style={styles.background}>
      <Header label={"Transaction Report"} />
      <div
        style={{
          ...{
            display: "flex",
            alignItems: "center",
            justifyContent: "center",
            height: "100%",
            width: "100%",
            minHeight: "100%",
            minWidth: "100%",
            flexWrap: "wrap",
          },
          ...styles.flex_column,
        }}
      >
        <PDFDownloadLink
          document={
            <TransactionReportPDF
              transactions={transactions.data || []}
              filter="Day"
            />
          }
          fileName="transaction.pdf"
        >
          {({ loading }) =>
            loading ? "Loading document..." : "Download Transaction"
          }
        </PDFDownloadLink>
        <PDFViewer style={{ width: "90%", height: "80vh" }}>
          <TransactionReportPDF
            transactions={transactions.data || []}
            filter="Day"
          />
        </PDFViewer>
      </div>
    </div>
  );
}
